@@ -288,7 +288,7 @@ class ContentReplacementServiceApi(BpkioSdkConsumer):
 
     def upsert(
         self, service: Svc.ContentReplacementServiceIn, if_exists: str = "retrieve"
-    ) -> Tuple[Svc.ContentReplacementService, int]:
+    ) -> Tuple[Svc.ContentReplacementService, UpsertOperationType]:
         """Conditionally create, retrieve or update a Content Replacement service"""
         return self.parent_api.upsert(
             service, unique_fields=["url"], if_exists=if_exists
@@ -427,7 +427,7 @@ class VirtualChannelServiceApi(BpkioSdkConsumer):
 
     def upsert(
         self, service: Svc.VirtualChannelServiceIn, if_exists: str = "retrieve"
-    ) -> Tuple[Svc.VirtualChannelService, int]:
+    ) -> Tuple[Svc.VirtualChannelService, UpsertOperationType]:
         """Conditionally create, retrieve or update a Virtual Channel service"""
         return self.parent_api.upsert(
             service, unique_fields=["url"], if_exists=if_exists
@@ -570,7 +570,7 @@ class AdInsertionServiceApi(BpkioSdkConsumer):
 
     def upsert(
         self, service: Svc.AdInsertionServiceIn, if_exists: str = "retrieve"
-    ) -> Tuple[Svc.AdInsertionService, int]:
+    ) -> Tuple[Svc.AdInsertionService, UpsertOperationType]:
         """Conditionally create, retrieve or update an Ad Insertion service"""
         return self.parent_api.upsert(
             service, unique_fields=["url"], if_exists=if_exists
