@@ -32,7 +32,7 @@ class SourceFormat(Enum):
 
 
 class SourceIn(NamedModel, PropertyMixin):
-    url: AnyHttpUrl
+    url: AnyHttpUrl | str
 
     @property
     def full_url(self):
