@@ -1,12 +1,14 @@
 from datetime import datetime
 from typing import Optional
 
+from bpkio_api.models.common import BaseModel, NamedModel
 from pydantic import PrivateAttr
 
-from bpkio_api.models.common import BaseResource, NamedModel
 
+class Tenant(NamedModel):
+    id: Optional[int] = None
 
-class Tenant(BaseResource, NamedModel):
+    email: Optional[str]
     # TODO - Turn to enum
     commercialPlan: str
     # TODO - Turn to enum
